API Reference
=============

In this part of the documentation, we will cover **Flask-Jeroboam**'s internals.

.. toctree::
    :caption: Contents:
    :maxdepth: 2

    jeroboam
    view
    functions
